@@ -59,6 +59,12 @@ void prot_the_line(const char *func_name, int theLine_of_code, size_t the_line_t
 
 void prot_the_line_pc(Chunk *pc_sub, const char *func_name, int theLine_of_code, size_t the_line_to_be_prot, size_t partNumber)
 {
+   if (pc_sub->IsNullChunk())
+   {
+      LOG_FMT(LGUY, "Prot_the_line:(%s:%d) Chunk::GetHead() is not set\n", func_name, theLine_of_code);
+      return;
+   }
+
    if (the_line_to_be_prot == 0)
    {
       // use the option debug_line_number_to_protocol.
@@ -151,6 +157,10 @@ void prot_the_line_pc(Chunk *pc_sub, const char *func_name, int theLine_of_code,
             }
          }
       }
+      else if (pc->GetOrigLine() > the_line_to_be_prot)
+      {
+         break;
+      }
    }
 
    LOG_FMT(LGUY, "\n");
@@ -826,7 +836,7 @@ void set_dump_file_name(const char *name)
 }
 
 
-//! give the oportunity to examine most(all) the data members of a single token
+//! give the opportunity to examine most(all) the data members of a single token
 //! may be inserted everythere to follow a value
 void examine_token(const char *func_name, int theLine_of_code, size_t orig_line_to_examine, size_t orig_column_to_examine)
 {
